==> open-cluster-management-discovery-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiscoveryConfigSpecFluent<A extends DiscoveryConfigSpecFluent<A>> extends BaseFluent<A>{
  public DiscoveryConfigSpecFluent() {
  }
  public DiscoveryConfigSpecFluent(DiscoveryConfigSpec instance) {
    instance = (instance != null ? instance : new DiscoveryConfigSpec());

    if (instance != null) {
      this.withCredential(instance.getCredential());
      this.withFilters(instance.getFilters());
      this.withCredential(instance.getCredential());
      this.withFilters(instance.getFilters());
    }
  }
  private String credential;
  private FilterBuilder filters;
  public String getCredential() {
    return this.credential;
  }
  public A withCredential(String credential) {
    this.credential=credential; return (A) this;
  }
  public boolean hasCredential() {
    return this.credential != null;
  }
  public Filter buildFilters() {
    return this.filters!=null ?this.filters.build():null;
  }
  public A withFilters(Filter filters) {
    _visitables.get("filters").remove(this.filters);
    if (filters!=null){ this.filters= new FilterBuilder(filters); _visitables.get("filters").add(this.filters);} else { this.filters = null; _visitables.get("filters").remove(this.filters); } return (A) this;
  }
  public boolean hasFilters() {
    return this.filters != null;
  }
  public FiltersNested<A> withNewFilters() {
    return new FiltersNested(null);
  }
  public FiltersNested<A> withNewFiltersLike(Filter item) {
    return new FiltersNested(item);
  }
  public FiltersNested<A> editFilters() {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(null));
  }
  public FiltersNested<A> editOrNewFilters() {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(new FilterBuilder().build()));
  }
  public FiltersNested<A> editOrNewFiltersLike(Filter item) {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiscoveryConfigSpecFluent that = (DiscoveryConfigSpecFluent) o;
    if (!java.util.Objects.equals(credential, that.credential)) return false;

    if (!java.util.Objects.equals(filters, that.filters)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credential,  filters,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credential != null) { sb.append("credential:"); sb.append(credential + ","); }
    if (filters != null) { sb.append("filters:"); sb.append(filters); }
    sb.append("}");
    return sb.toString();
  }
  public class FiltersNested<N> extends FilterFluent<FiltersNested<N>> implements Nested<N>{
    FiltersNested(Filter item) {
      this.builder = new FilterBuilder(this, item);
    }
    FilterBuilder builder;
    public N and() {
      return (N) DiscoveryConfigSpecFluent.this.withFilters(builder.build());
    }
    public N endFilters() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-discovery-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DiscoveryConfigSpecFluent<A extends DiscoveryConfigSpecFluent<A>> extends BaseFluent<A>{
  public DiscoveryConfigSpecFluent() {
  }
  
  public DiscoveryConfigSpecFluent(DiscoveryConfigSpec instance) {
    this.copyInstance(instance);
  }
  private String credential;
  private FilterBuilder filters;
  
  protected void copyInstance(DiscoveryConfigSpec instance) {
    instance = (instance != null ? instance : new DiscoveryConfigSpec());
  
    if (instance != null) {
        this.withCredential(instance.getCredential());
        this.withFilters(instance.getFilters());
        this.withCredential(instance.getCredential());
        this.withFilters(instance.getFilters());
      }
  }
  
  public String getCredential() {
    return this.credential;
  }
  
  public A withCredential(String credential) {
    this.credential=credential; return (A) this;
  }
  
  public boolean hasCredential() {
    return this.credential != null;
  }
  
  public Filter buildFilters() {
    return this.filters!=null ?this.filters.build():null;
  }
  
  public A withFilters(Filter filters) {
    _visitables.get("filters").remove(this.filters);
    if (filters!=null){ this.filters= new FilterBuilder(filters); _visitables.get("filters").add(this.filters);} else { this.filters = null; _visitables.get("filters").remove(this.filters); } return (A) this;
  }
  
  public boolean hasFilters() {
    return this.filters != null;
  }
  
  public FiltersNested<A> withNewFilters() {
    return new FiltersNested(null);
  }
  
  public FiltersNested<A> withNewFiltersLike(Filter item) {
    return new FiltersNested(item);
  }
  
  public FiltersNested<A> editFilters() {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(null));
  }
  
  public FiltersNested<A> editOrNewFilters() {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(new FilterBuilder().build()));
  }
  
  public FiltersNested<A> editOrNewFiltersLike(Filter item) {
    return withNewFiltersLike(java.util.Optional.ofNullable(buildFilters()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiscoveryConfigSpecFluent that = (DiscoveryConfigSpecFluent) o;
    if (!java.util.Objects.equals(credential, that.credential)) return false;
  
    if (!java.util.Objects.equals(filters, that.filters)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(credential,  filters,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credential != null) { sb.append("credential:"); sb.append(credential + ","); }
    if (filters != null) { sb.append("filters:"); sb.append(filters); }
    sb.append("}");
    return sb.toString();
  }
  public class FiltersNested<N> extends FilterFluent<FiltersNested<N>> implements Nested<N>{
    FiltersNested(Filter item) {
      this.builder = new FilterBuilder(this, item);
    }
    FilterBuilder builder;
    
    public N and() {
      return (N) DiscoveryConfigSpecFluent.this.withFilters(builder.build());
    }
    
    public N endFilters() {
      return and();
    }
    
  
  }

}
